@@ -471,8 +471,6 @@ class _BaseAuthProtocol(object):
         :type request: _request.AuthTokenRequest
 
         """
-        request.remove_auth_headers()
-
         user_auth_ref = None
         serv_auth_ref = None
 
@@ -487,7 +485,7 @@ class _BaseAuthProtocol(object):
                 request.user_token_valid = False
             else:
                 request.user_token_valid = True
-                request.environ['keystone.token_info'] = data
+                request.token_info = data
 
         if request.service_token:
             self.log.debug('Authenticating service token')
@@ -501,8 +499,8 @@ class _BaseAuthProtocol(object):
             else:
                 request.service_token_valid = True
 
-        p = _user_plugin.UserAuthPlugin(user_auth_ref, serv_auth_ref)
-        request.environ['keystone.token_auth'] = p
+        request.token_auth = _user_plugin.UserAuthPlugin(user_auth_ref,
+                                                         serv_auth_ref)
 
     def _validate_token(self, auth_ref):
         """Perform the validation steps on the token.
@@ -512,7 +510,7 @@ class _BaseAuthProtocol(object):
 
         :raises exc.InvalidToken: if token is rejected
         """
-        # 0 seconds of validity means is it valid right now.
+        # 0 seconds of validity means it is invalid right now
         if auth_ref.will_expire_soon(stale_duration=0):
             raise exc.InvalidToken(_('Token authorization failed'))
 
@@ -722,6 +720,7 @@ class AuthProtocol(_BaseAuthProtocol):
         request for use by applications. If not authenticated the request will
         be rejected or marked unauthenticated depending on configuration.
         """
+        request.remove_auth_headers()
         self._token_cache.initialize(request.environ)
 
         resp = super(AuthProtocol, self).process_request(request)
@@ -839,9 +838,8 @@ class AuthProtocol(_BaseAuthProtocol):
                 data = cached
 
                 if self._check_revocations_for_cached:
-                    # A token stored in Memcached might have been revoked
-                    # regardless of initial mechanism used to validate it,
-                    # and needs to be checked.
+                    # A token might have been revoked, regardless of initial
+                    # mechanism used to validate it, and needs to be checked.
                     self._revocations.check(token_hashes)
             else:
                 data = self._validate_offline(token, token_hashes)
@@ -883,18 +881,6 @@ class AuthProtocol(_BaseAuthProtocol):
                                  'fallback to online validation.'))
         else:
             data = jsonutils.loads(verified)
-
-            audit_ids = None
-            if 'access' in data:
-                # It's a v2 token.
-                audit_ids = data['access']['token'].get('audit_ids')
-            else:
-                # It's a v3 token
-                audit_ids = data['token'].get('audit_ids')
-
-            if audit_ids:
-                self._revocations.check_by_audit_id(audit_ids)
-
             return data
 
     def _validate_token(self, auth_ref):
@@ -1085,15 +1071,11 @@ class AuthProtocol(_BaseAuthProtocol):
             env_cache_name=self._conf_get('cache'),
             memcached_servers=self._conf_get('memcached_servers'),
             use_advanced_pool=self._conf_get('memcache_use_advanced_pool'),
-            memcache_pool_dead_retry=self._conf_get(
-                'memcache_pool_dead_retry'),
-            memcache_pool_maxsize=self._conf_get('memcache_pool_maxsize'),
-            memcache_pool_unused_timeout=self._conf_get(
-                'memcache_pool_unused_timeout'),
-            memcache_pool_conn_get_timeout=self._conf_get(
-                'memcache_pool_conn_get_timeout'),
-            memcache_pool_socket_timeout=self._conf_get(
-                'memcache_pool_socket_timeout'),
+            dead_retry=self._conf_get('memcache_pool_dead_retry'),
+            maxsize=self._conf_get('memcache_pool_maxsize'),
+            unused_timeout=self._conf_get('memcache_pool_unused_timeout'),
+            conn_get_timeout=self._conf_get('memcache_pool_conn_get_timeout'),
+            socket_timeout=self._conf_get('memcache_pool_socket_timeout'),
         )
 
         if security_strategy:
