@@ -12,19 +12,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-__all__ = [
+__all__ = (
     'list_auth_token_opts',
-]
+)
 
 import copy
 
 import keystonemiddleware.auth_token
-
+from keystonemiddleware.auth_token import _auth
+from keystonemiddleware.auth_token import _base
 
 auth_token_opts = [
-    (keystonemiddleware.auth_token._AUTHTOKEN_GROUP,
+    (_base.AUTHTOKEN_GROUP,
      keystonemiddleware.auth_token._OPTS +
-     keystonemiddleware.auth_token._AuthTokenPlugin.get_options())
+     _auth.AuthTokenPlugin.get_options())
 ]
 
 
